#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_THREEEPS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_THREEEPS_HPP_INCLUDED

#include <boost/simd/constant/include/constants/threeeps.hpp>

#endif
